@@ -5,4 +5,4 @@ from .lpStateVar import LPStateVar_timedep
 from .lpStateVar import LPStateVar_add
 from .lpMain import LPMain
 from .equation import Equation as Eq
-from .tools import plot_sum
\ No newline at end of file
+from .tools import plot_sum, Solver,Obj
\ No newline at end of file
