@@ -1,5 +1,5 @@
 import numpy as np
-from .lpStateVar import LPStateVar, LPStateVar_timedep,LPStateVar_add,LPStateVar_Decision_add,LPStateVar_Decision_timedep
+from .lpStateVar import *
 from .lpInputdata import LPInputdata
 from scipy.sparse import coo_matrix, csc_matrix
 from .equation import Equation as Eq
@@ -129,8 +129,16 @@ class LPObject:
             sense (str): ">","=" or "<"
             b (float): right side of equation
             description (str): optiional short description of equation
-        """        
-        self.eq_lst.append(Eq(var_lst,sense,b,description))
+        """
+        if any(len(var)==2 and (isinstance(var[0],LPStateVar_timedep) or isinstance(var[0],LPStateVar_Decision_timedep)) for var in var_lst):
+            if isinstance(b,list)or isinstance(b,np.ndarray):
+                for t in range(self.inputdata.steps):
+                    self.eq_lst.append(Eq([[var[0],var[1],t] for var in var_lst],sense,b[t],description))
+            else:
+                for t in range(self.inputdata.steps):
+                    self.eq_lst.append(Eq([[var[0],var[1],t] for var in var_lst],sense,b,description))
+        else:
+            self.eq_lst.append(Eq(var_lst,sense,b,description))
     
     def getStateVars(self)->list[LPStateVar]:
         '''greturns list of state_vars'''
